@@ -3,11 +3,10 @@ from __future__ import annotations
 import asyncio
 
 from mitmproxy import ctx
+from mitmproxy.utils import asyncio_utils
 
 
 class KeepServing:
-    _watch_task: asyncio.Task | None = None
-
     def load(self, loader):
         loader.add_option(
             "keepserving",
@@ -44,4 +43,8 @@ class KeepServing:
             ctx.options.rfile,
         ]
         if any(opts) and not ctx.options.keepserving:
-            self._watch_task = asyncio.get_running_loop().create_task(self.watch())
+            asyncio_utils.create_task(
+                self.watch(),
+                name="keepserving",
+                keep_ref=True,
+            )
